@@ -31,11 +31,11 @@ def exampleMain():
 
     # Context is used to store information that should be shared between file sections, such as mapping the symbol vram's to its name and more
     context = spimdisasm.common.Context()
-    context.globalSegment.changeRanges(0x0, 0xFFFFFFFF, 0x0, 0xFFFFFFFF)
+    context.changeGlobalSegmentRanges(0x0, 0xFFFFFFFF, 0x0, 0xFFFFFFFF)
 
     # Read whole binary input file
-    array_of_bytes = spimdisasm.common.Utils.readFileAsBytearray(args.binary)
-    inputName = pathlib.Path(args.binary).stem
+    inputPath = pathlib.Path(args.binary)
+    array_of_bytes = spimdisasm.common.Utils.readFileAsBytearray(inputPath)
 
     start = int(args.start, 16)
     end = int(args.end, 16)
@@ -45,7 +45,7 @@ def exampleMain():
     truncatedInputBytes = array_of_bytes[start:end]
 
     # Asume the input is a .text section. Insntance a SectionText and analyze it
-    textSection = spimdisasm.mips.sections.SectionText(context, start, end, fileVram, inputName, truncatedInputBytes, 0, None)
+    textSection = spimdisasm.mips.sections.SectionText(context, start, end, fileVram, inputPath.stem, truncatedInputBytes, 0, None)
     textSection.analyze()
     textSection.setCommentOffset(start)
 
