@@ -109,6 +109,14 @@ class ElementBase:
         pass
 
 
+    def getSpimdisasmVersionString(self) -> str:
+        if not GlobalConfig.ASM_COMMENT or not GlobalConfig.ASM_GENERATED_BY:
+            return ""
+
+        from .. import __version__
+        return f"/* Generated by spimdisasm {__version__} */{GlobalConfig.LINE_ENDS}{GlobalConfig.LINE_ENDS}"
+
+
     def disassemble(self, migrate: bool=False, useGlobalLabel: bool=True) -> str:
         """Produces a disassembly of this element.
 
