@@ -5,6 +5,8 @@
 
 from __future__ import annotations
 
+from pathlib import Path
+
 from .. import common
 
 from . import sections
@@ -15,7 +17,7 @@ from . import FileBase, createEmptyFile
 
 class FileSplits(FileBase):
     def __init__(self, context: common.Context, vromStart: int, vromEnd: int, vram: int, filename: str, array_of_bytes: bytearray, segmentVromStart: int, overlayCategory: str|None, splitsData: common.FileSplitFormat|None=None, relocSection: sections.SectionRelocZ64|None=None):
-        super().__init__(context, vromStart, vromEnd, vram, filename, array_of_bytes, common.FileSectionType.Unknown, segmentVromStart, overlayCategory)
+        super().__init__(context, vromStart, vromEnd, vram, filename, common.Utils.bytesToWords(array_of_bytes, vromStart, vromEnd), common.FileSectionType.Unknown, segmentVromStart, overlayCategory)
 
         self.sectionsDict: dict[common.FileSectionType, dict[str, sections.SectionBase]] = {
             common.FileSectionType.Text: dict(),
@@ -72,7 +74,7 @@ class FileSplits(FileBase):
             # if self.vram is None:
             #     self.vram = splitEntry.vram
 
-            f = FilesHandlers.createSectionFromSplitEntry(splitEntry, array_of_bytes, splitEntry.fileName, context)
+            f = FilesHandlers.createSectionFromSplitEntry(splitEntry, array_of_bytes, Path(splitEntry.fileName), context)
             f.parent = self
             f.setCommentOffset(splitEntry.offset)
 
@@ -99,7 +101,7 @@ class FileSplits(FileBase):
             for section in sectDict.values():
                 words += section.words
         buffer = bytearray(4*len(words))
-        common.Utils.beWordsToBytes(words, buffer)
+        common.Utils.wordsToBytes(words, buffer)
         return common.Utils.getStrHash(buffer)
 
     def analyze(self):
