@@ -237,7 +237,7 @@ class SymbolFunction(SymbolText):
 
         # Symbols
         for loOffset, symVram in self.instrAnalyzer.symbolLoInstrOffset.items():
-            if symVram in self.context.bannedSymbols:
+            if self.context.isAddressBanned(symVram):
                 continue
 
             # Check for user-defined symbol patches
@@ -366,7 +366,7 @@ class SymbolFunction(SymbolText):
         for i in range(self.nInstr-1, 0-1, -1):
             instr = self.instructions[i]
             if not instr.isNop():
-                if instr.isJrRa():
+                if instr.isReturn():
                     first_nop += 1
                 break
             first_nop = i
@@ -496,7 +496,7 @@ class SymbolFunction(SymbolText):
             if not self.pointersRemoved and instructionOffset in self.instrAnalyzer.symbolInstrOffset:
                 address = self.instrAnalyzer.symbolInstrOffset[instructionOffset]
 
-                if address in self.context.bannedSymbols:
+                if self.context.isAddressBanned(address):
                     return None
 
                 symbol: common.ContextSymbol|None = None
@@ -634,10 +634,15 @@ class SymbolFunction(SymbolText):
     def disassemble(self, migrate: bool=False, useGlobalLabel: bool=True) -> str:
         output = ""
 
+        if migrate:
+            output += self.getSpimdisasmVersionString()
+
         if not common.GlobalConfig.DISASSEMBLE_UNKNOWN_INSTRUCTIONS:
             if self.hasUnimplementedIntrs:
                 return self.disassembleAsData(useGlobalLabel=useGlobalLabel)
 
+        output += self.getReferenceeSymbols()
+
         if self.isLikelyHandwritten:
             if not self.isRsp:
                 # RSP functions are always handwritten, so this is redundant
